==> opensaml-xacml-saml-impl-3.3.0-sources.jar: org/opensaml/xacml/profile/saml/impl/XACMLAuthzDecisionQueryTypeImplBuilder.java <==
/*
 * Licensed to the University Corporation for Advanced Internet Development,
 * Inc. (UCAID) under one or more contributor license agreements.  See the
 * NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The UCAID licenses this file to You under the Apache
 * License, Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opensaml.xacml.profile.saml.impl;

import org.opensaml.saml.common.AbstractSAMLObjectBuilder;
import org.opensaml.xacml.XACMLObjectBuilder;
import org.opensaml.xacml.profile.saml.XACMLAuthzDecisionQueryType;

/** Builder for {@link XACMLAuthzDecisionQueryType} objects. */
public class XACMLAuthzDecisionQueryTypeImplBuilder extends AbstractSAMLObjectBuilder<XACMLAuthzDecisionQueryType>
        implements XACMLObjectBuilder<XACMLAuthzDecisionQueryType> {

    /** Constructor. */
    public XACMLAuthzDecisionQueryTypeImplBuilder() {

    }

    /** {@inheritDoc} */
    public XACMLAuthzDecisionQueryType buildObject() {
        return null;
    }

    /** {@inheritDoc} */
    public XACMLAuthzDecisionQueryType buildObject(String namespaceURI, String localName, String namespacePrefix) {
        return new XACMLAuthzDecisionQueryTypeImpl(namespaceURI, localName, namespacePrefix);
    }
}

==> opensaml-xacml-saml-impl-4.0.1-sources.jar: org/opensaml/xacml/profile/saml/impl/XACMLAuthzDecisionQueryTypeImplBuilder.java <==
/*
 * Licensed to the University Corporation for Advanced Internet Development,
 * Inc. (UCAID) under one or more contributor license agreements.  See the
 * NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The UCAID licenses this file to You under the Apache
 * License, Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opensaml.xacml.profile.saml.impl;

import org.opensaml.saml.common.AbstractSAMLObjectBuilder;
import org.opensaml.xacml.XACMLObjectBuilder;
import org.opensaml.xacml.profile.saml.XACMLAuthzDecisionQueryType;

/** Builder for {@link XACMLAuthzDecisionQueryType} objects. */
public class XACMLAuthzDecisionQueryTypeImplBuilder extends AbstractSAMLObjectBuilder<XACMLAuthzDecisionQueryType>
        implements XACMLObjectBuilder<XACMLAuthzDecisionQueryType> {

    /** Constructor. */
    public XACMLAuthzDecisionQueryTypeImplBuilder() {

    }

    /** {@inheritDoc} */
    public XACMLAuthzDecisionQueryType buildObject() {
        return null;
    }

    /** {@inheritDoc} */
    public XACMLAuthzDecisionQueryType buildObject(final String namespaceURI, final String localName,
            final String namespacePrefix) {
        return new XACMLAuthzDecisionQueryTypeImpl(namespaceURI, localName, namespacePrefix);
    }
}
